==> gallery-1.4.4.6.tbz: www/data/gallery/locale/nl_NL/nl_NL-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2004 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: nl_NL-nls.php,v 1.5.2.4 2004/10/08 17:28:10 jenst Exp $
 *
 * Version: 1.4.4-pl4
 */
 
/*
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */


/*
** Native languagename
*/
	$nls['language']['nl_NL'] = 		'Nederlands';

/*
** Alias for languages with different browser and gettext codes
**/

	$nls['alias']['nl'] = 			'nl_NL';

/*
** Alias for languages which we substitte or send by NUKE
*/
	$nls['alias']['dutch'] = 		'nl_NL' ;
	$nls['alias']['nld'] =                  'nl_NL' ;
	$nls['alias']['nl_BE'] = 		'nl_NL' ;
	$nls['alias']['nl_NL.ISO8859-1'] =	'nl_NL' ;
	
/*
** phpNuke
*/
	$nls['phpnuke']['nl_NL'] = 		'dutch';

/*
** postNuke
*/

	$nls['postnuke']['nl_NL'] =             'nld';
?>

==> gallery-1.5.4_1.tbz: www/data/gallery/locale/nl_NL/nl_NL-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: nl_NL-nls.php,v 1.13.2.2 2005/09/12 22:41:04 dmolavi Exp $
  */
 
/**
 * @version	1.5.1
 * @package	Languagepack
 * @subpackage	Dutch
 */

/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz.
 * (jens@peino.de)
 */

/**
 * Native languagename
 */
	$nls['language']['nl_NL'] = 		'Nederlands';

/**
 * Aliases for languages with different browser and gettext codes
 */
	$nls['alias']['nl'] = 			'nl_NL';

/**
 * Aliases for languages which we substitte or send by NUKE, GeekLog or Mambo
 */
	$nls['alias']['dutch'] = 		'nl_NL' ;
	$nls['alias']['nld'] =                  'nl_NL' ;
	$nls['alias']['nl_BE'] = 		'nl_NL' ;
	$nls['alias']['nl_NL.ISO8859-1'] =	'nl_NL' ;

/**
 * phpNuke
 */
	$nls['phpnuke']['nl_NL'] = 		'dutch';

/**
 * postNuke
 */
	$nls['postnuke']['nl_NL'] =             'nld';

?>
